netapp_ontap.models.snaplock_log_archive API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.snaplock_log_archive`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SnaplockLogArchiveSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SnaplockLogArchive object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `archive: bool PATCH`

    Archive the specified SnapLock log file for the given base_name, and create a new log file. If base_name is not mentioned, archive all log files.

  `base_name: str PATCH`

    Base name of log archive

    Valid choices:

    - legal_hold
    - privileged_delete
    - system
  `links: SelfLink GET`

    The links field of the snaplock_log_archive.